@@ -1,6 +1,9 @@
 package App::TimeClock;
 
-our $VERSION = "0.12";
+use strict;
+use warnings;
+
+our $VERSION = "0.13";
 
 =head1 NAME
 
